function A = A2(Ts,Td,Dc,mu,T0,T0i)
% Returns critical area of initiation zone (IZ) in m2 
% leading to runaway rupture using A2 estimate by Galis et al. (GJI 2015).
%
% IZ is overstressed asperity, i.e., the initial traction inside IZ is expected
% to be higher than static traction. 
% Function displays a warning and returns -1 if it is not so.
%
% Ts - static traction/stress [Pa]
% Td - dynamic traction/stress [Pa]
% Dc - characteristic slip-weakeing distance [m]
% mu - shear modulus [Pa]
% T0 - initiatl traction outside the initiation zone [Pa]
% T0i - initiation traction inside the initiation zone [Pa]
%
% This estimate is valid for S > ~0.75 assuming Poisson's ratio ~0.25
% For lower S, estimate by Uenishi 2009 is sufficient for a runaway rupture 
% See Galis et al., 2015 for more details.
%
% For Poisson's ratio ~0.25 and
%        S < ~0.75 this estimate leads to a RUNAWAY rupture
%        S > ~0.75 this estimate leads to s STOPPING ruptures.
%                 For runaway ruptures use A1 or A2 by Galis et al., 2015
%
% for full details please see Appendix A of  
% Galis, M., Pelties, C., Kristek, J., Moczo, P., Ampuero,  J.-P., Mai, P. M., 2015.  
%    On the initiation of sustained slip-weakening ruptures by localized stresses 
%    Geophys. J. Int., 200, 888-907, doi: 10.1093/gji/ggu436
%
%--------------------------------------------------------------------------
% Written by 
%      Martin Galis, May 2015                        martin.galis@kaust.edu.sa
%--------------------------------------------------------------------------

    if T0i <= Ts
      A = -1;
      disp('T0i is lower than Ts, please check input parameters.');
      return
    end

    gamma = (T0i - T0) / (T0 - Td);

    % fminsearch gives position of minimum
    xmin = fminsearch( @(x) ...
              sqrt(x) * ( 1 + gamma * ( 1 - sqrt( 1 - 1/x^2 ) ) ),    1);

    % use the position of the minimum to obtain fmin
    fmin = sqrt(xmin) * ( 1 + gamma * ( 1 - sqrt( 1 - 1/xmin^2 ) ) );

    A =   (pi)^3 * mu^2 * Dc^2 *           (Ts - Td)^2        ...
      / (  16    *                   ((T0 - Td)* fmin)^4  );
        
end